#!/usr/bin/python

'''
A module to manage the chunk hierarchy - holds the contents of files, though for large files that'll be
split up into multiple smaller chunks
'''

#mport os
#mport sys
import time
#mport errno

import adbm
import python2x3
import dirops_mod
#mport constants_mod
#mport compressed_file_mod


def timestamp():
    '''Return a timestamp as a string'''
    # Another option would be to make it a base255 or something, but it's nice having the extra
    # precision of fractional number
    return str(time.time())


class Chunk:
    '''Perform operations (read, write, update timestamp) on a chunk (of a file)'''

    # We don't actually use this, but chunk_mod_traditional would
    canonical_hostname = None

    data_db = None
    time_db = None

    first_time = True

    def __init__(self, digest):
        self.digest = python2x3.string_to_binary(digest)
        self.possible_init()

    @classmethod
    def possible_init(cls):
        '''If this is the first time we are called, mkdir chunks and open/create our databases'''
        # We don't just do this as class stuff (outer level still inside the class), because then
        # chunks is created in the wrong place - we want this post-chdir()
        if cls.first_time:
            dirops_mod.my_mkdir('chunks')

            cls.data_db = adbm.open('chunks/data', 'c')
            cls.time_db = adbm.open('chunks/time', 'c')

            cls.first_time = False

    def write_or_touch_chunk(self, chunk_bytes):
        '''
        If the chunk is not yet present, add the chunk and add a tiestamp.  Return 0 to indicate we skipped nothing.
        If the chunk is already present, just update the timestamp.  Rather the length of the chunk.
        '''
        if self.digest in Chunk.data_db and self.digest in Chunk.time_db:
            self.update_timestamp()
            return 0
        else:
            Chunk.data_db[self.digest] = chunk_bytes
            self.update_timestamp()
            return len(chunk_bytes)

    def read_chunk(self):
        '''Read a chunk_bytes back'''
        return self.data_db[self.digest]

    def update_timestamp(self):
        '''Update the timestamp on a chunk (hash)'''

        Chunk.time_db[self.digest] = timestamp()


def finalize():
    '''Close the databases'''

    if Chunk.data_db is not None:
        #sys.stderr.write('Closing data_db\n')
        Chunk.data_db.close()
    if Chunk.time_db is not None:
        #sys.stderr.write('Closing time_db\n')
        Chunk.time_db.close()


