#!/usr/bin/env python

'''Provides a bunch of str/bytes constants, so we aren't converting and reconverting incessantly'''

import python2x3


class Constants:
    # pylint: disable=W0232,R0903
    # W0232: We don't need an __init__ for a container
    # R0903: We don't need public methods for a container
    '''Just a simple container for lots of things we need as bytes'''

    # First some file metadata attributes
    b_block_device = python2x3.string_to_binary('block_device')
    b_block_major = python2x3.string_to_binary('block_major')
    b_block_minor = python2x3.string_to_binary('block_minor')
    b_character_device = python2x3.string_to_binary('character_device')
    b_character_major = python2x3.string_to_binary('character_major')
    b_character_minor = python2x3.string_to_binary('character_minor')
    b_directory = python2x3.string_to_binary('directory')
    b_fifo = python2x3.string_to_binary('fifo')
    b_group = python2x3.string_to_binary('group')
    b_hardlink = python2x3.string_to_binary('hardlink')
    b_hash = python2x3.string_to_binary('hash')
    b_link_target = python2x3.string_to_binary('link_target')
    b_owner = python2x3.string_to_binary('owner')
    b_regular_file = python2x3.string_to_binary('regular_file')
    b_st_atime = python2x3.string_to_binary('st_atime')
    b_st_ctime = python2x3.string_to_binary('st_ctime')
    b_st_dev = python2x3.string_to_binary('st_dev')
    b_st_gid = python2x3.string_to_binary('st_gid')
    b_st_ino = python2x3.string_to_binary('st_ino')
    b_st_mode = python2x3.string_to_binary('st_mode')
    b_st_mtime = python2x3.string_to_binary('st_mtime')
    b_st_size = python2x3.string_to_binary('st_size')
    b_st_uid = python2x3.string_to_binary('st_uid')
    b_symlink = python2x3.string_to_binary('symlink')

    # Some single character things for string manipulation
    b_newline = python2x3.string_to_binary('\n')
    b_blank = python2x3.string_to_binary(' ')
    b_minus = python2x3.string_to_binary('-')

    # Some directory-related constants
    b_dot = python2x3.string_to_binary('.')
    b_slash_dir_dash = python2x3.string_to_binary('/dir-')
    b_slash = python2x3.string_to_binary('/')
    b_hat_dot_slash = python2x3.string_to_binary(r'^\./')
    b_hat_dir_dash = python2x3.string_to_binary('^dir-')
    b_dir_dash = python2x3.string_to_binary('dir-')

    # Some file extensions
    b_dot_data = python2x3.string_to_binary('.data')
    b_dot_time = python2x3.string_to_binary('.time')

    # Some file/directory commponents
    b_chunks = python2x3.string_to_binary('chunks')
    b_files = python2x3.string_to_binary('files')
    s_entries = 'entries'
    b_entries = python2x3.string_to_binary(s_entries)
    b_data = python2x3.string_to_binary('data')
    b_time = python2x3.string_to_binary('time')

    # Some miscellaneous constants
    b_true = python2x3.string_to_binary('True')
    b_false = python2x3.string_to_binary('False')
    file_type_width = 7

    # Some characters for grouping
    b_a = python2x3.string_to_binary('a')
    b_z = python2x3.string_to_binary('z')
    b_A = python2x3.string_to_binary('A')
    b_Z = python2x3.string_to_binary('Z')
    b_0 = python2x3.string_to_binary('0')
    b_1 = python2x3.string_to_binary('1')
    b_2 = python2x3.string_to_binary('2')
    b_3 = python2x3.string_to_binary('3')
    b_4 = python2x3.string_to_binary('4')
    b_5 = python2x3.string_to_binary('5')
    b_6 = python2x3.string_to_binary('6')
    b_7 = python2x3.string_to_binary('7')
    b_8 = python2x3.string_to_binary('8')
    b_9 = python2x3.string_to_binary('9')
    b_underscore = python2x3.string_to_binary('_')
    b_special = python2x3.string_to_binary('`~!@#$%^&*()-_=+[{]}\\|;:",<.>/?' + "'")
    b_onenewline = python2x3.string_to_binary('1\n')

